| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Test.Tasty.Ingredients.Rerun
Synopsis
- rerunningTests :: [Ingredient] -> Ingredient
Documentation
rerunningTests :: [Ingredient] -> Ingredient Source #
This Ingredient transformer allows to control
which tests to run depending on their previous outcomes.
For example, you can rerun only failing tests or only new tests.
The behaviour is controlled by command-line options:
--rerun-updateUpdate the log file to reflect latest test outcomes.
--rerun-filterCATEGORIESRead the log file and rerun only tests from a given comma-separated list of categories:
failures,exceptions,new,successful. If this option is omitted or the log file is missing, rerun everything.--rerun-log-fileFILELocation of the log file (default:
.tasty-rerun-log).
Usage example:
import Test.Tasty
import Test.Tasty.Runners
import Test.Tasty.Ingredients.Rerun
main :: IO ()
main =
defaultMainWithIngredients
[ rerunningTests [ listingTests, consoleTestReporter ] ]
tests
tests :: TestTree
tests = undefined